@@ -1,9 +1,9 @@
 #!perl
 use Moose::Util qw( with_traits );
 use lib '../lib';
-use Data::Walk::Extracted 0.024;
-use Data::Walk::Prune 0.024;
-use Data::Walk::Print 0.024;
+use Data::Walk::Extracted;
+use Data::Walk::Prune;
+use Data::Walk::Print;
 
 my  $edward_scissorhands = with_traits(
 		'Data::Walk::Extracted',
